@@ -4,6 +4,7 @@ pub mod math;
 pub mod code;
 pub mod theatre;
 pub mod novel;
+pub mod beamer;
 
 use basic::*;
 use book::*;
@@ -11,3 +12,4 @@ use math::*;
 use code::*;
 use theatre::*;
 use novel::*;
+use beamer::*;
\ No newline at end of file
