@@ -1,6 +1,7 @@
 use crate::Templates::*;
 use std::io::Write;
-
+use std::path::Path;
+use std::fs::create_dir;
 fn const_conv(main: &str, structure: &str)-> (String, String) {
     (main.to_string(), structure.to_string())
 }
@@ -24,11 +25,24 @@ pub fn create(name: &str, file_path: &Option<String>, template: &str) {
         None => "."
     };
     let (main, structure) = load(template);
-    std::fs::create_dir(format!("{}/{}", file_path, name)).unwrap();
+    let path = format!("{}/{}", file_path, name);
+    let def_path = format!("{}/{}_texcreate", file_path, name);
+    let mut p = String::new();
+    // Check if directory exists, if it does, use def
+    // else create the directory 
+    if Path::new(&path).exists(){
+        println!("Creating {}", &def_path);
+        create_dir(&def_path).expect("Error in creating directory");
+        p = def_path;
+    } else {
+        println!("Creating {}", &def_path);
+        create_dir(&path).expect("Error in creating directory");
+        p = path;
+    }
     let mut main_file =
-        std::fs::File::create(format!("{}/{}/{}.tex", file_path, name, name)).unwrap();
+        std::fs::File::create(format!("{}/{}.tex", &p, name)).unwrap();
     main_file.write_all(main.as_bytes()).unwrap();
     let mut structure_file =
-        std::fs::File::create(format!("{}/{}/structure.tex", file_path, name)).unwrap();
+        std::fs::File::create(format!("{}/structure.tex", &p)).unwrap();
     structure_file.write_all(structure.as_bytes()).unwrap();
 }
\ No newline at end of file
